
:autogenerated:

krotov.result module
====================

.. currentmodule:: krotov.result

.. automodule:: krotov.result
    :members: Result
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Classes:

    .. autosummary::
        :nosignatures:

        Result





    ``__all__``: :class:`Result <krotov.result.Result>`



    Reference
    ---------